Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: include/core/SkMatrix.h

Issue 295713002: Rename SkMatrix::get(Min|Max)Stretch to get(Min|Max)Scale (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: rename Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/core/SkBitmapProcShader.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/core/SkMatrix.h
diff --git a/include/core/SkMatrix.h b/include/core/SkMatrix.h
index e225336bd845218eea5c91feb4492a929df8aab1..d52ab67f8c968896af88abd163356d232ed364f5 100644
--- a/include/core/SkMatrix.h
+++ b/include/core/SkMatrix.h
@@ -563,20 +563,20 @@ public:
SK_TO_STRING_NONVIRT()
/**
- * Calculates the minimum stretching factor of the matrix. If the matrix has
+ * Calculates the minimum scaling factor of the matrix. If the matrix has
* perspective -1 is returned.
*
* @return minumum strecthing factor
*/
- SkScalar getMinStretch() const;
+ SkScalar getMinScale() const;
/**
* Calculates the maximum stretching factor of the matrix. If the matrix has
* perspective -1 is returned.
*
* @return maximum strecthing factor
*/
- SkScalar getMaxStretch() const;
+ SkScalar getMaxScale() const;
/**
* Return a reference to a const identity matrix
« no previous file with comments | « no previous file | src/core/SkBitmapProcShader.cpp » ('j') | no next file with comments »
@@ -563,20 +563,20 @@ public:
* perspective -1 is returned.
*
- * @return minumum strecthing factor
+ * @return minumum scale factor
*/
@@ -563,20 +563,20 @@ public:
/**
- * Calculates the maximum stretching factor of the matrix. If the matrix has
+ * Calculates the maximum scale factor of the matrix. If the matrix has
* perspective -1 is returned.
*
@@ -563,20 +563,20 @@ public:
* perspective -1 is returned.
*
- * @return maximum strecthing factor
+ * @return maximum scale factor
*/

Powered by Google App Engine
This is Rietveld 408576698